@@ -13,16 +13,15 @@ Pickle implementation of DatasetMetadataAbstract
 
 """
 
+
 class DatasetMetadataPickle(DatasetsMetaDataAbstractDict):
-     
-     def __init__(self,destenation,source=None) -> None:
-         super().__init__(destenation,source)
-         if (self.source is not None):
+
+    def __init__(self, destenation, source=None) -> None:
+        super().__init__(destenation, source)
+        if (self.source is not None):
             self.data = pd.read_pickle(self.source)
-     
-     def create(self):
-          self.data.to_pickle(self.destenation)
-     
-     
-     
-     
\ No newline at end of file
+        else:
+            self.data = pd.DataFrame([])
+
+    def create(self):
+        self.data.to_pickle(self.destenation)
